Resource

Enum Resource 

pub enum Resource {
Show 13 variants Cpu, Powergrid, Calibration, DroneBay, DroneBandwidth, LaunchedDrones, FighterBay, FighterTubes, LightFighterTubes, SupportFighterTubes, HeavyFighterTubes, CargoBay, ChargeCapacity,
}
A resource the ship only has so much of.

Variants



Cpu

CPU.



Powergrid

Powergrid.



Calibration

Calibration, which the rigs take up.



DroneBay

Room in the drone bay.



DroneBandwidth

Bandwidth for the drones in space.



LaunchedDrones

Drones in space at once.



FighterBay

Room in the fighter bay.



FighterTubes

Fighter tubes.



LightFighterTubes

Tubes that take a light squadron.



SupportFighterTubes

Tubes that take a support squadron.



HeavyFighterTubes

Tubes that take a heavy squadron.



CargoBay

Room in the cargo hold.



ChargeCapacity

Room in the module for the charge it holds.