pub enum Slot {
High(u8),
Medium(u8),
Low(u8),
Rig(u8),
Subsystem(u8),
Service(u8),
FighterTube(u8),
FighterBay,
Implant(u8),
Booster(u16),
DroneBay,
Cargo,
}Expand description
Where an item is. The number is the position in its rack, starting at 0; for implants and boosters, the slot as EVE numbers it, starting at 1.
Variants
High(u8)
A high slot.
Medium(u8)
A medium slot.
Low(u8)
A low slot.
Rig(u8)
A rig slot.
Subsystem(u8)
A subsystem slot.
Service(u8)
A service slot, on a structure.
FighterTube(u8)
A fighter tube; a squadron that is not offline is in space.
FighterBay
The fighter bay; nothing in it is in space.
Implant(u8)
An implant; the number is its implantness.
Booster(u16)
A booster; the number is its boosterness.
DroneBay
The drone bay; a drone that is not offline is in space.
Cargo
The cargo hold; nothing in it is calculated.