pub struct Environment {
pub damage_profile: DamageProfile,
pub security: Security,
pub reactive_armor: ReactiveArmor,
}Expand description
Where the ship is.
Fields
damage_profile: DamageProfileThe damage the ship is assumed to take, for effective hitpoints.
security: SecurityThe security of the solar system.
reactive_armor: ReactiveArmorWhat a Reactive Armor Hardener shifts its resistances towards.