ItemResult

Struct ItemResult 

pub struct ItemResult {
    pub attributes: BTreeMap<i32, AttributeValue>,
    pub state: State,
    pub max_state: State,
    pub charge: Option<Box<ItemResult>>,
}
The calculated attributes of the ship, its mode, the character, or one item.

Fields

attributes: BTreeMap<i32, AttributeValue>

Every attribute, by attribute id.

state: State

The state actually reached, which may be below what was requested.

max_state: State

The highest state the item can reach.

charge: Option<Box<ItemResult>>

The charge loaded in the module, if any.